// DO NOT EDIT -- generated by mk-ops.awk
#if ! defined (octave_mx_i8nda_i16_h)
#define octave_mx_i8nda_i16_h 1
#include "octave-config.h"
#include "int8NDArray.h"
#include "oct-inttypes.h"
  extern OCTAVE_API boolNDArray mx_el_lt (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_le (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_ge (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_gt (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_eq (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_ne (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_and (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_or (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_not_and (const int8NDArray&, const octave_int16&);
  extern OCTAVE_API boolNDArray mx_el_not_or (const int8NDArray&, const octave_int16&);
#endif
